==> auraxium-0.2.0b1.tar.gz: auraxium-0.2.0b1/auraxium/ps2/__init__.py <==
"""Object representations for the PlanetSide 2 API.

This is a higher-level abstraction of the data accessible through the
census. Note that the object attributes and hierarchy of this object
model will not match up to the Census API perfectly.
"""

from ._ability import Ability, AbilityType, ResourceType
from ._achievement import Achievement
from ._armour import ArmourFacing, ArmourInfo
from ._character import Character, Title
from ._currency import Currency
from ._depot import MarketingBundle, MarketingBundleSingle
from ._directive import (Directive, DirectiveTier, DirectiveTree,
                         DirectiveTreeCategory)
from ._effect import Effect, EffectType, TargetType
from ._experience import Experience, ExperienceRank
from ._faction import Faction
from ._fire import FireGroup, FireMode, FireModeType
from ._item import Item, ItemCategory, ItemType
from . import leaderboard
from ._map import FacilityType, MapHex, MapRegion, Region
from ._metagame import MetagameEvent, MetagameEventState
from ._objective import Objective, ObjectiveType
from ._outfit import Outfit, OutfitMember
from ._profile import Loadout, Profile
from ._projectile import Projectile, ProjectileFlightType
from ._resist import ResistInfo, ResistType
from ._reward import Reward, RewardType
from ._skill import Skill, SkillCategory, SkillLine, SkillSet
from ._states import PlayerState, PlayerStateGroup
from ._vehicle import Vehicle, VehicleAttachment
from ._weapon import Weapon, WeaponAmmoSlot, WeaponDatasheet
from ._world import World
from ._zone import Zone
from ._zone_effect import ZoneEffect, ZoneEffectType

__all__ = [
    'Ability',
    'AbilityType',
    'Achievement',
    'ArmourFacing',
    'ArmourInfo',
    'Character',
    'Currency',
    'MarketingBundle',
    'MarketingBundleSingle',
    'Directive',
    'DirectiveTier',
    'DirectiveTree',
    'DirectiveTreeCategory',
    'Effect',
    'EffectType',
    'Experience',
    'ExperienceRank',
    'FacilityType',
    'Faction',
    'FireGroup',
    'FireMode',
    'FireModeType',
    'Item',
    'ItemCategory',
    'ItemType',
    'leaderboard',
    'Loadout',
    'MapHex',
    'MapRegion',
    'Region',
    'MetagameEvent',
    'MetagameEventState',
    'Objective',
    'ObjectiveType',
    'Outfit',
    'OutfitMember',
    'Profile',
    'Projectile',
    'ProjectileFlightType',
    'ResistInfo',
    'ResistType',
    'ResourceType',
    'Reward',
    'RewardType',
    'Skill',
    'SkillCategory',
    'SkillLine',
    'SkillSet',
    'TargetType',
    'Title',
    'PlayerState',
    'PlayerStateGroup',
    'Vehicle',
    'VehicleAttachment',
    'Weapon',
    'WeaponAmmoSlot',
    'WeaponDatasheet',
    'World',
    'Zone',
    'ZoneEffect',
    'ZoneEffectType'
]

==> auraxium-0.2.3.tar.gz: auraxium-0.2.3/auraxium/ps2/__init__.py <==
"""Object representations for the PlanetSide 2 API.

This is a higher-level abstraction of the data accessible through the
census. Note that the object attributes and hierarchy of this object
model will not match up to the Census API perfectly.
"""

from ._ability import Ability, AbilityType, ResourceType
from ._achievement import Achievement
from ._armour import ArmourFacing, ArmourInfo
from ._character import Character, Title
from ._currency import Currency
from ._depot import MarketingBundle, MarketingBundleSingle
from ._directive import (Directive, DirectiveTier, DirectiveTree,
                         DirectiveTreeCategory)
from ._effect import Effect, EffectType, TargetType, ZoneEffect, ZoneEffectType
from ._experience import Experience, ExperienceRank
from ._faction import Faction
from ._fire import FireGroup, FireMode, FireModeType
from ._item import Item, ItemCategory, ItemType
from . import leaderboard
from ._map import FacilityType, MapHex, MapRegion, Region
from ._metagame import MetagameEvent, MetagameEventState
from ._objective import Objective, ObjectiveType
from ._outfit import Outfit, OutfitMember
from ._profile import Loadout, Profile
from ._projectile import Projectile, ProjectileFlightType
from ._resist import ResistInfo, ResistType
from ._reward import Reward, RewardType
from ._skill import Skill, SkillCategory, SkillLine, SkillSet
from ._states import PlayerState, PlayerStateGroup
from ._vehicle import Vehicle, VehicleAttachment
from ._weapon import Weapon, WeaponAmmoSlot, WeaponDatasheet
from ._world import World
from ._zone import Zone

__all__ = [
    'Ability',
    'AbilityType',
    'Achievement',
    'ArmourFacing',
    'ArmourInfo',
    'Character',
    'Currency',
    'MarketingBundle',
    'MarketingBundleSingle',
    'Directive',
    'DirectiveTier',
    'DirectiveTree',
    'DirectiveTreeCategory',
    'Effect',
    'EffectType',
    'Experience',
    'ExperienceRank',
    'FacilityType',
    'Faction',
    'FireGroup',
    'FireMode',
    'FireModeType',
    'Item',
    'ItemCategory',
    'ItemType',
    'leaderboard',
    'Loadout',
    'MapHex',
    'MapRegion',
    'Region',
    'MetagameEvent',
    'MetagameEventState',
    'Objective',
    'ObjectiveType',
    'Outfit',
    'OutfitMember',
    'Profile',
    'Projectile',
    'ProjectileFlightType',
    'ResistInfo',
    'ResistType',
    'ResourceType',
    'Reward',
    'RewardType',
    'Skill',
    'SkillCategory',
    'SkillLine',
    'SkillSet',
    'TargetType',
    'Title',
    'PlayerState',
    'PlayerStateGroup',
    'Vehicle',
    'VehicleAttachment',
    'Weapon',
    'WeaponAmmoSlot',
    'WeaponDatasheet',
    'World',
    'Zone',
    'ZoneEffect',
    'ZoneEffectType'
]
